@@ -30,28 +30,33 @@ class ErrorCodes(object):
         BillingAddressIdIsInvalid = "91702"
         CardholderNameIsTooLong = "81723"
         CreditCardTypeIsNotAccepted = "81703"
-        CustomerIdIsRequired = "91704"
+        CreditCardTypeIsNotAcceptedBySubscriptionMerchantAccount = "81718"
         CustomerIdIsInvalid = "91705"
-        CvvIsRequired = "81706"
+        CustomerIdIsRequired = "91704"
         CvvIsInvalid = "81707"
+        CvvIsRequired = "81706"
         ExpirationDateConflict = "91708"
-        ExpirationDateIsRequired = "81709"
         ExpirationDateIsInvalid = "81710"
+        ExpirationDateIsRequired = "81709"
         ExpirationDateYearIsInvalid = "81711"
         ExpirationMonthIsInvalid = "81712"
         ExpirationYearIsInvalid = "81713"
-        NumberIsRequired = "81714"
-        NumberIsInvalid = "81715"
         NumberHasInvalidLength = "81716"
+        NumberIsInvalid = "81715"
+        NumberIsRequired = "81714"
         NumberMustBeTestNumber = "81717"
         TokenInvalid = "91718"
         TokenIsInUse = "91719"
-        TokenIsTooLong = "91720"
         TokenIsNotAllowed = "91721"
         TokenIsRequired = "91722"
+        TokenIsTooLong = "91720"
+
+        class Options(object):
+            UpdateExistingTokenIsInvalid = "91723"
+
 
     class Customer(object):
-        CompanyisTooLong = "81601"
+        CompanyIsTooLong = "81601"
         CustomFieldIsInvalid = "91602"
         CustomFieldIsTooLong = "81603"
         EmailIsInvalid = "81604"
@@ -72,6 +77,10 @@ class ErrorCodes(object):
         CannotEditCanceledSubscription = "81901"
         IdIsInUse = "81902"
         MerchantAccountIdIsInvalid = "91901"
+        PaymentMethodTokenCardTypeIsNotAccepted = "91902"
+        PaymentMethodTokenIsInvalid = "91903"
+        PaymentMethodTokenNotAssociatedWithCustomer = "91905"
+        PlanIdIsInvalid = "91904"
         PriceCannotBeBlank = "81903"
         PriceFormatIsInvalid = "81904"
         StatusIsCanceled = "81905"
@@ -85,6 +94,7 @@ class ErrorCodes(object):
         AmountIsRequired = "81502"
         AmountIsInvalid = "81503"
         AmountIsTooLarge = "81528"
+        BillingAddressConflict = "91530"
         CannotBeVoided = "91504"
         CannotRefundCredit = "91505"
         CannotRefundUnlessSettled = "91506"
